#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernières révisions       : 24/01/2009
#
#package			: paintown
#homepage			: http://paintown.sourceforge.net/
#source location	: http://ovh.dl.sourceforge.net/sourceforge/paintown/paintown-3.2.tar.gz
#dependency         : 

softname='paintown'
softversion='3.2'
packageversion='62.1'

#
# ZenWalk standard: type CPUet architecture
#
# arch='i486' -> le compileur utilise seulement les instructions 80486
# cpu='i686'  -> optimisation faîte pour PII et >
#
arch='i486'
cpu='i686'

#
# destination du package
#
prefix=/usr

#
# log
#
(

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# "gros" PC: 6 compilations à la fois
#
# numjobs='-j6'
#
# "léger" PC: 2 compilations à la fois
#
numjobs='-j2'

#
# paramètres pour compiler
#
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://ovh.dl.sourceforge.net/sourceforge/paintown/$softname-$softversion.tar.gz

#
# preparer le répertoire qui accueillera la compilation
#
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/src/$softname-$softversion

#
# mettre le slack-desc en place. 
#
cat <<EOF > $dest/install/slack-desc 
        |-----handy-ruler------------------------------------------------------|
paintown: paintown - An open source fighting game
paintown:
paintown: Paintown is an open source fighting game in the same genre as 
paintown: Streets of Rage and Teenage Mutant Ninja Turtles. 
paintown: 
paintown: 
paintown: 
paintown: 
paintown: 
paintown: 
paintown:
EOF

#
# Verifie si package est present
#
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

#
# extraire les sources
#
# tar.gz : tar zxvf $srcpkg
# tar.bz2: tar xjvf $srcpkg
# tgz    : tar xzvf $srcpkg
#
cd $buildir
tar xzvf $srcpkg
cd $src	

#
# "faire" le package package
#
#sed -i "s|-O2|-O2 -march=i486 -mtune=i686|g" SConstruct

patch -p1  < ../paintown-3.2-zenflags.patch

scons

#
# installer le package dans son répertoire de destination
#
./install.sh -d $dest/usr/share/$softname -b $dest/usr/bin


#
# faire le fichier .desktop
#
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Paintown
Comment=Fighting game
Exec=paintown
Icon=paintown
Terminal=false
Type=Application
Categories=Game;ActionGame;
Encoding=UTF-8
EOF

cat <<EOF > $dest/usr/bin/paintown
#!/bin/sh
exec /usr/share/paintown/paintown-bin -d /usr/share/paintown/data -w
EOF

chmod 755 $dest/usr/bin/paintown
   
cp ../paintown.png  $dest/usr/share/icons/hicolor/48x48/apps
   
#
# ajout des fichiers de docs, infos, ...
#
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      LEGAL LICENSE README TODO\
      $dest/usr/doc/$softname-$softversion
    	
#
# Stripper les éxécutables
# (Commenter ces lignes si besoin d'infos de débuggage)
#
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#
# Mettre le zenbuild à sa place
#
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

#
# fixer les permissions
#
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#
# fabriquer le zenpackage
#
cd $dest
makepkg -l y -c n $dest.tgz

#
# produire la signature md5 du package
#
cd $buildir
md5sum $package.tgz > $package.md5

#
# produire le fichier .dep
#
cd $buildir
echo -e "allegro,cxxlibs,freetype,gcc,gcc-g++,libpng,python,xcb,xorg-libs,zlib" > $package.dep

#
# produire le fichier source
#
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/supertuxkart/source/build-paintown.sh > $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/supertuxkart/source/paintown-3.2-zenflags.patch >> $package.src
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/games/supertuxkart/source/paintown.png >> $package.src
echo $source >> $package.src

#
# supprimer source
#
rm -rf $src
rm -rf $dest

#
# log
#
) 2>&1 | tee "$softname-$softversion-build.log"
